==> craftedcore-fabric-1.20.1-5-sources.jar: tocraft/craftedcore/fabric/mixin/client/GuiMixin.java <==
package tocraft.craftedcore.fabric.mixin.client;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_329;
import net.minecraft.class_332;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.craftedcore.event.client.RenderEvents;

@SuppressWarnings("unused")
@Environment(EnvType.CLIENT)
@Mixin(class_329.class)
public abstract class GuiMixin {

    @Shadow
    protected abstract class_1657 getCameraPlayer();

    @Inject(method = "renderPlayerHealth", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Player;isEyeInFluid(Lnet/minecraft/tags/TagKey;)Z"), cancellable = true)
    //#if MC>1194
    private void shouldRenderBreath(class_332 guiGraphics, CallbackInfo ci) {
    //#else
    //$$ private void shouldRenderBreath(PoseStack guiGraphics, CallbackInfo ci) {
    //#endif
        class_1269 result = RenderEvents.RENDER_BREATH.invoke().render(guiGraphics, this.getCameraPlayer());
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }

    @Inject(method = "renderHearts", at = @At(value = "HEAD"), cancellable = true)
    //#if MC>1194
    private void shouldRenderHealth(class_332 guiGraphics, class_1657 player, int x, int y, int height, int offsetHeartIndex, float maxHealth, int currentHealth, int displayHealth, int absorptionAmount, boolean renderHighlight, CallbackInfo ci) {
    //#else
    //$$ private void shouldRenderHealth(PoseStack guiGraphics, Player player, int x, int y, int height, int offsetHeartIndex, float maxHealth, int currentHealth, int displayHealth, int absorptionAmount, boolean renderHighlight, CallbackInfo ci) {
    //#endif
        class_1269 result = RenderEvents.RENDER_HEALTH.invoke().render(guiGraphics, player);
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }

    //#if MC>=1205
    @Inject(method = "renderFood", at = @At(value = "HEAD"), cancellable = true)
    private void shouldRenderFood(class_332 guiGraphics, class_1657 player, int y, int x, CallbackInfo ci) {
        class_1269 result = RenderEvents.RENDER_FOOD.invoke().render(guiGraphics, player);
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }
    //#else
    //$$ @ModifyExpressionValue(method = "renderPlayerHealth", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/Gui;getVehicleMaxHearts(Lnet/minecraft/world/entity/LivingEntity;)I"))
    //$$ private int shouldRenderFood(int health) {
    //$$     InteractionResult result = RenderEvents.RENDER_FOOD.invoke().render(null, Minecraft.getInstance().player);
    //$$     if (result == InteractionResult.FAIL) {
    //$$         return -1;
    //$$     }
    //$$     return health;
    //$$ }
    //#endif

    @Inject(method = "renderVehicleHealth", at = @At(value = "HEAD"), cancellable = true)
    //#if MC>1194
    private void shouldRenderMountHealth(class_332 guiGraphics, CallbackInfo ci) {
    //#else
    //$$ private void shouldRenderMountHealth(PoseStack guiGraphics, CallbackInfo ci) {
        //#endif
        class_1269 result = RenderEvents.RENDER_MOUNT_HEALTH.invoke().render(guiGraphics, this.getCameraPlayer());
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }
}

==> craftedcore-fabric-1.20.2-4.2.2-sources.jar: tocraft/craftedcore/fabric/mixin/client/GuiMixin.java <==
package tocraft.craftedcore.fabric.mixin.client;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_310;
import net.minecraft.class_329;
import net.minecraft.class_332;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.craftedcore.event.client.RenderEvents;

@SuppressWarnings("unused")
@Environment(EnvType.CLIENT)
@Mixin(class_329.class)
public abstract class GuiMixin {

    @Shadow
    protected abstract class_1657 getCameraPlayer();

    @Inject(method = "renderPlayerHealth", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Player;isEyeInFluid(Lnet/minecraft/tags/TagKey;)Z"), cancellable = true)
    private void shouldRenderBreath(class_332 guiGraphics, CallbackInfo ci) {
        class_1269 result = RenderEvents.RENDER_BREATH.invoke().render(guiGraphics, this.getCameraPlayer());
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }

    @Inject(method = "renderHearts", at = @At(value = "HEAD"), cancellable = true)
    private void shouldRenderHealth(class_332 guiGraphics, class_1657 player, int x, int y, int height, int offsetHeartIndex, float maxHealth, int currentHealth, int displayHealth, int absorptionAmount, boolean renderHighlight, CallbackInfo ci) {
        class_1269 result = RenderEvents.RENDER_HEALTH.invoke().render(guiGraphics, player);
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }

    @ModifyExpressionValue(method = "renderPlayerHealth", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/Gui;getVehicleMaxHearts(Lnet/minecraft/world/entity/LivingEntity;)I"))
    private int shouldRenderFood(int health) {
        class_1269 result = RenderEvents.RENDER_FOOD.invoke().render(null, class_310.method_1551().field_1724);
        if (result == class_1269.field_5814) {
            return -1;
        }
        return health;
    }

    @Inject(method = "renderVehicleHealth", at = @At(value = "HEAD"), cancellable = true)
    private void shouldRenderMountHealth(class_332 guiGraphics, CallbackInfo ci) {
        class_1269 result = RenderEvents.RENDER_MOUNT_HEALTH.invoke().render(guiGraphics, this.getCameraPlayer());
        if (result == class_1269.field_5814) {
            ci.cancel();
        }
    }
}
